# input-tel

## Dépendances
```shell
input-tel
└─ core
└─ form
└─ input-base
```

## Utilisation
Afin d’utiliser le composant `input-tel`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
    <link href="css/form/form.min.css" rel="stylesheet">
    <link href="css/button/button.min.css" rel="stylesheet">
    <link href="css/input-base/input-base.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/blocs-fonctionnels/numero-de-telephone) sur le module Bloc fonctionnel de numéro de téléphone